# OhMyAdmin

Awesome admin panel for your business.

![PyPI](https://img.shields.io/pypi/v/ohmyadmin)
![GitHub Workflow Status](https://img.shields.io/github/workflow/status/alex-oleshkevich/ohmyadmin/Lint%20and%20test)
![GitHub](https://img.shields.io/github/license/alex-oleshkevich/ohmyadmin)
![Libraries.io dependency status for latest release](https://img.shields.io/librariesio/release/pypi/ohmyadmin)
![PyPI - Downloads](https://img.shields.io/pypi/dm/ohmyadmin)
![GitHub Release Date](https://img.shields.io/github/release-date/alex-oleshkevich/ohmyadmin)

## Installation

Install `ohmyadmin` using PIP or poetry:

```bash
pip install ohmyadmin
# or
poetry add ohmyadmin
```

## Features

-   TODO

## Quick start

See example application in `examples/` directory of this repository.
